Rename getFixedStack to getStackObject. The stack objects represented are not
necessarily fixed. Only those will negative frame indices are "fixed."


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@84315 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/PseudoSourceValue.cpp b/lib/CodeGen/PseudoSourceValue.cpp
index 00c5d46..e74479e 100644
--- a/lib/CodeGen/PseudoSourceValue.cpp
+++ b/lib/CodeGen/PseudoSourceValue.cpp
@@ -52,29 +52,31 @@
 }
 
 namespace {
   /// FixedStackPseudoSourceValue - A specialized PseudoSourceValue
   /// for holding FixedStack values, which must include a frame
   /// index.
-  class VISIBILITY_HIDDEN FixedStackPseudoSourceValue
+  class VISIBILITY_HIDDEN StackObjectPseudoSourceValue
     : public PseudoSourceValue {
     const int FI;
   public:
-    explicit FixedStackPseudoSourceValue(int fi) : FI(fi) {}
+    explicit StackObjectPseudoSourceValue(int fi) : FI(fi) {}
 
     virtual bool isConstant(const MachineFrameInfo *MFI) const;
 
     virtual void printCustom(raw_ostream &OS) const {
-      OS << "FixedStack" << FI;
+      if (FI < 0)
+        OS << "Fixed";
+      OS << "StackObject" << FI;
     }
   };
 }
 
 static ManagedStatic<std::map<int, const PseudoSourceValue *> > FSValues;
 
-const PseudoSourceValue *PseudoSourceValue::getFixedStack(int FI) {
+const PseudoSourceValue *PseudoSourceValue::getStackObject(int FI) {
   const PseudoSourceValue *&V = (*FSValues)[FI];
   if (!V)
-    V = new FixedStackPseudoSourceValue(FI);
+    V = new StackObjectPseudoSourceValue(FI);
   return V;
 }
 
@@ -89,6 +91,7 @@
   return false;
 }
 
-bool FixedStackPseudoSourceValue::isConstant(const MachineFrameInfo *MFI) const{
+bool
+StackObjectPseudoSourceValue::isConstant(const MachineFrameInfo *MFI) const {
   return MFI && MFI->isImmutableObjectIndex(FI);
 }
@@ -52,29 +52,31 @@
 
 namespace {
-  /// FixedStackPseudoSourceValue - A specialized PseudoSourceValue
-  /// for holding FixedStack values, which must include a frame
+  /// StackObjectPseudoSourceValue - A specialized PseudoSourceValue
+  /// for holding StackObject values, which must include a frame
   /// index.